@@ -1,23 +1,27 @@
-import logging
+import os
 import re
 import time
 
 from dask.distributed import Client as DaskClient
 from importlib_metadata import entry_points
 from jupyter_ai.chat_handlers.learn import Retriever
+from jupyter_ai_magics import JupyternautPersona
 from jupyter_ai_magics.utils import get_em_providers, get_lm_providers
 from jupyter_server.extension.application import ExtensionApp
+from tornado.web import StaticFileHandler
 from traitlets import Dict, List, Unicode
 
 from .chat_handlers import (
     AskChatHandler,
     ClearChatHandler,
     DefaultChatHandler,
+    ExportChatHandler,
     GenerateChatHandler,
     HelpChatHandler,
     LearnChatHandler,
 )
-from .chat_handlers.help import HelpMessage
+from .chat_handlers.help import build_help_message
+from .completions.handlers import DefaultInlineCompletionHandler
 from .config_manager import ConfigManager
 from .handlers import (
     ApiKeysHandler,
@@ -28,6 +32,11 @@ from .handlers import (
     RootChatHandler,
 )
 
+JUPYTERNAUT_AVATAR_ROUTE = JupyternautPersona.avatar_route
+JUPYTERNAUT_AVATAR_PATH = str(
+    os.path.join(os.path.dirname(__file__), "static", "jupyternaut.svg")
+)
+
 
 class AiExtension(ExtensionApp):
     name = "jupyter_ai"
@@ -38,6 +47,15 @@ class AiExtension(ExtensionApp):
         (r"api/ai/chats/history?", ChatHistoryHandler),
         (r"api/ai/providers?", ModelProviderHandler),
         (r"api/ai/providers/embeddings?", EmbeddingsModelProviderHandler),
+        (r"api/ai/completion/inline/?", DefaultInlineCompletionHandler),
+        # serve the default persona avatar at this path.
+        # the `()` at the end of the URL denotes an empty regex capture group,
+        # required by Tornado.
+        (
+            rf"{JUPYTERNAUT_AVATAR_ROUTE}()",
+            StaticFileHandler,
+            {"path": JUPYTERNAUT_AVATAR_PATH},
+        ),
     ]
 
     allowed_providers = List(
@@ -104,6 +122,38 @@ class AiExtension(ExtensionApp):
         config=True,
     )
 
+    default_language_model = Unicode(
+        default_value=None,
+        allow_none=True,
+        help="""
+        Default language model to use, as string in the format
+        <provider-id>:<model-id>, defaults to None.
+        """,
+        config=True,
+    )
+
+    default_embeddings_model = Unicode(
+        default_value=None,
+        allow_none=True,
+        help="""
+        Default embeddings model to use, as string in the format
+        <provider-id>:<model-id>, defaults to None.
+        """,
+        config=True,
+    )
+
+    default_api_keys = Dict(
+        key_trait=Unicode(),
+        value_trait=Unicode(),
+        default_value=None,
+        allow_none=True,
+        help="""
+        Default API keys for model providers, as a dictionary,
+        in the format `<key-name>:<key-value>`. Defaults to None.
+        """,
+        config=True,
+    )
+
     def initialize_settings(self):
         start = time.time()
 
@@ -122,6 +172,13 @@ class AiExtension(ExtensionApp):
         self.settings["model_parameters"] = self.model_parameters
         self.log.info(f"Configured model parameters: {self.model_parameters}")
 
+        defaults = {
+            "model_provider_id": self.default_language_model,
+            "embeddings_provider_id": self.default_embeddings_model,
+            "api_keys": self.default_api_keys,
+            "fields": self.model_parameters,
+        }
+
         # Fetch LM & EM providers
         self.settings["lm_providers"] = get_lm_providers(
             log=self.log, restrictions=restrictions
@@ -140,6 +197,7 @@ class AiExtension(ExtensionApp):
             blocked_providers=self.blocked_providers,
             allowed_models=self.allowed_models,
             blocked_models=self.blocked_models,
+            defaults=defaults,
         )
 
         self.log.info("Registered providers.")
@@ -166,19 +224,24 @@ class AiExtension(ExtensionApp):
         # requires the event loop to be running on init. So instead we schedule
         # this as a task that is run as soon as the loop starts, and pass
         # consumers a Future that resolves to the Dask client when awaited.
-        dask_client_future = loop.create_task(self._get_dask_client())
+        self.settings["dask_client_future"] = loop.create_task(self._get_dask_client())
 
         eps = entry_points()
-        # initialize chat handlers
-        chat_handler_eps = eps.select(group="jupyter_ai.chat_handlers")
 
-        chat_handler_kwargs = {
+        common_handler_kargs = {
             "log": self.log,
             "config_manager": self.settings["jai_config_manager"],
+            "model_parameters": self.settings["model_parameters"],
+        }
+
+        # initialize chat handlers
+        chat_handler_eps = eps.select(group="jupyter_ai.chat_handlers")
+        chat_handler_kwargs = {
+            **common_handler_kargs,
             "root_chat_handlers": self.settings["jai_root_chat_handlers"],
             "chat_history": self.settings["chat_history"],
             "root_dir": self.serverapp.root_dir,
-            "dask_client_future": dask_client_future,
+            "dask_client_future": self.settings["dask_client_future"],
             "model_parameters": self.settings["model_parameters"],
         }
         default_chat_handler = DefaultChatHandler(**chat_handler_kwargs)
@@ -192,12 +255,14 @@ class AiExtension(ExtensionApp):
         retriever = Retriever(learn_chat_handler=learn_chat_handler)
         ask_chat_handler = AskChatHandler(**chat_handler_kwargs, retriever=retriever)
 
+        export_chat_handler = ExportChatHandler(**chat_handler_kwargs)
         jai_chat_handlers = {
             "default": default_chat_handler,
             "/ask": ask_chat_handler,
             "/clear": clear_chat_handler,
             "/generate": generate_chat_handler,
             "/learn": learn_chat_handler,
+            "/export": export_chat_handler,
         }
 
         help_chat_handler = HelpChatHandler(
@@ -253,13 +318,59 @@ class AiExtension(ExtensionApp):
         # Make help always appear as the last command
         jai_chat_handlers["/help"] = help_chat_handler
 
-        self.settings["chat_history"].append(
-            HelpMessage(chat_handlers=jai_chat_handlers)
-        )
+        # bind chat handlers to settings
         self.settings["jai_chat_handlers"] = jai_chat_handlers
 
+        # show help message at server start
+        self._show_help_message()
+
         latency_ms = round((time.time() - start) * 1000)
         self.log.info(f"Initialized Jupyter AI server extension in {latency_ms} ms.")
 
+    def _show_help_message(self):
+        """
+        Method that ensures a dynamically-generated help message is included in
+        the chat history shown to users.
+        """
+        chat_handlers = self.settings["jai_chat_handlers"]
+        config_manager: ConfigManager = self.settings["jai_config_manager"]
+        lm_provider = config_manager.lm_provider
+
+        if not lm_provider:
+            return
+
+        persona = config_manager.persona
+        unsupported_slash_commands = (
+            lm_provider.unsupported_slash_commands if lm_provider else set()
+        )
+        help_message = build_help_message(
+            chat_handlers, persona, unsupported_slash_commands
+        )
+        self.settings["chat_history"].append(help_message)
+
     async def _get_dask_client(self):
         return DaskClient(processes=False, asynchronous=True)
+
+    async def stop_extension(self):
+        """
+        Public method called by Jupyter Server when the server is stopping.
+        This calls the cleanup code defined in `self._stop_exception()` inside
+        an exception handler, as the server halts if this method raises an
+        exception.
+        """
+        try:
+            await self._stop_extension()
+        except Exception as e:
+            self.log.error("Jupyter AI raised an exception while stopping:")
+            self.log.exception(e)
+
+    async def _stop_extension(self):
+        """
+        Private method that defines the cleanup code to run when the server is
+        stopping.
+        """
+        if "dask_client_future" in self.settings:
+            dask_client: DaskClient = await self.settings["dask_client_future"]
+            self.log.info("Closing Dask client.")
+            await dask_client.close()
+            self.log.debug("Closed Dask client.")
