@@ -15,6 +15,7 @@ from langchain.pydantic_v1 import ValidationError
 from tornado import web, websocket
 from tornado.web import HTTPError
 
+from .completions.models import InlineCompletionRequest
 from .models import (
     AgentChatMessage,
     ChatClient,
@@ -115,8 +116,12 @@ class RootChatHandler(JupyterHandler, websocket.WebSocketHandler):
         """Retrieves the current user. If `jupyter_collaboration` is not
         installed, one is synthesized from the server's current shell
         environment."""
-        collaborative = self.config.ServerApp.jpserver_extensions.get_value({}).get(
-            "jupyter_collaboration", False
+        # Get a dictionary of all loaded extensions.
+        # (`serverapp` is a property on all `JupyterHandler` subclasses)
+        extensions = self.serverapp.extension_manager.extensions
+        collaborative = (
+            "jupyter_collaboration" in extensions
+            and extensions["jupyter_collaboration"].enabled
         )
 
         if collaborative:
@@ -297,10 +302,6 @@ class ModelProviderHandler(ProviderHandler):
 
         # Step 1: gather providers
         for provider in self.lm_providers.values():
-            # skip old legacy OpenAI chat provider used only in magics
-            if provider.id == "openai-chat":
-                continue
-
             optionals = {}
             if provider.model_id_label:
                 optionals["model_id_label"] = provider.model_id_label
